@@ -2,8 +2,6 @@ import gettext
 from gettext import gettext as _
 import os
 
-print 'initialized i18n'
-
 def C_(ctx, s):
     """Provide qualified translatable strings via context.
     (copied from Orca)"""
@@ -14,7 +12,7 @@ def C_(ctx, s):
     return translated
 
 gettext.bindtextdomain ("caribou",
-                        os.path.join ("/usr/local", "share", "locale"))
+                        os.path.join ("/opt/testing-gnome3", "share", "locale"))
 
 gettext.textdomain("caribou")
 
